@@ -4,6 +4,7 @@ OC.L10N.register(
     "Can not add feed: Exists already" : "لا يمكن اضافة هذا الملقم:هو موجود بالفعل",
     "Articles without feed" : "مقالات بدون ملقم",
     "Can not add folder: Exists already" : "لا يمكن اضافة المجلد:موجود بالفعل",
+    "News" : "الأخبار",
     "Saved" : "حفظ",
     "Download" : "تنزيل",
     "Close" : "إغلاق",
@@ -23,6 +24,7 @@ OC.L10N.register(
     "New Folder" : "مجلد جديد",
     "Create" : "انشئ",
     "Rename" : "إعادة التسمية",
+    "Delete" : "حذف ",
     "Dismiss" : "تراجع",
     "Collapse" : "طوي",
     "Starred" : "معلّم بنجمة.",
