@@ -24,7 +24,7 @@ OC.L10N.register(
     "Feed fetcher timeout" : "Čas nalaganja vira",
     "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Čas, ki je namenjen za nalaganje virov RSS ali Atom. Po tem času je nalaganje virov prekinjeno.",
     "Explore Service URL" : "Razišči spletni naslov storitve",
-    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "Če je vpisan, bo iz tega servisnega URLja prenesel sporočila za prikaz. Za preklop v vgrajen sistem, pusti to poljeprazno",
+    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "Če je podan, bo prek tega naslova URL storitve potekala poizvedba za vire in njihov i zbor. Za preklop v vgrajeno storitev določevanja, mora biti polje prazno.",
     "Saved" : "Shranjeno",
     "Download" : "Prejmi",
     "Close" : "Zapri",
@@ -36,14 +36,14 @@ OC.L10N.register(
     "No unread articles available" : "Ni neprebranih prispevkov",
     "Open website" : "Odpri spletišče",
     "Star article" : "Označi prispevek z zvezdico",
-    "Unstar article" : "Odstrani oznako prispevka",
+    "Unstar article" : "Odstrani zvezdico s prispevka",
     "Keep article unread" : "Obdrži kot neprebrano",
     "Remove keep article unread" : "Odstrani možnost neprebrano",
     "by" : "od",
     "from" : "od",
     "Play audio" : "Predvajaj zvok",
-    "Download video" : "Prejmi video",
     "Download audio" : "Prejmi zvok",
+    "Download video" : "Prejmi video",
     "Keyboard shortcut" : "Tipkovna bližnica",
     "Description" : "Opis",
     "right" : "desno",
@@ -86,9 +86,15 @@ OC.L10N.register(
     "Undo delete feed" : "Razveljavi brisanje vira",
     "Rename" : "Preimenuj",
     "Menu" : "Meni",
+    "Mark read" : "Označi kot prebrano",
+    "Unpin from top" : "Odpni z vrha",
     "Pin to top" : "Pripni na vrh",
+    "Newest first" : "najprej najnovejše",
+    "Oldest first" : "najprej najstarejše",
+    "Default order" : "Privzeta razvrstitev",
     "Enable full text" : "Omogoči polno besedilo",
     "Disable full text" : "Omogoči polno besedilo",
+    "Ignore updated" : "Prezri posodobljeno",
     "Delete" : "Izbriši",
     "Dismiss" : "Opusti",
     "Collapse" : "Skrči",
