@@ -24,11 +24,11 @@ OC.L10N.register(
     "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Maximum storlek på flödet i bytes. Om RSS/Atom sidan är större än detta värde, kommer uppdateringen att avbrytas.",
     "Feed fetcher timeout" : "Timeout för flödes-hämtare",
     "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Maximalt antal sekunder att vänta på att RSS/Atom flödet skall ladda. Om det tar längre tid avbryts uppdateringen.",
-    "Explore Service URL" : "Utforska tjänst-URL",
-    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "Om angiven kommer denna tjänsts URL bli förfrågad om visning av flöden i flödet för utforskarsektionen. För att falla tillbaks på den inbyggda utforskar tjänsten, lämna detta inmatningsfält tomt",
+    "Explore Service URL" : "Utforska tjänstwebbadress",
+    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "Om angiven kommer denna tjänsts webbadress bli förfrågad om visning av flöden i flödet för utforskarsektionen. För att falla tillbaks på den inbyggda utforskar tjänsten, lämna detta inmatningsfält tomt\n\nOm detta anges kommer den här tjänstens webbadress att bli förfrågad av visning av flöden i avsnittet utforska flödet. För att återgå till den inbyggda utforskartjänsten, lämna det här inmatningsfältet tomt",
     "For more information check the wiki" : "För mer information, se wiki.",
     "Saved" : "Sparad",
-    "Download" : "Ladda ned",
+    "Download" : "Hämta",
     "Close" : "Stäng",
     "filter" : "filter",
     "Language" : "Språk",
@@ -44,8 +44,8 @@ OC.L10N.register(
     "by" : "av",
     "from" : "från",
     "Play audio" : "Spela ljud",
-    "Download video" : "Ladda ned video",
-    "Download audio" : "Ladda ned ljud",
+    "Download audio" : "Hämta ljud",
+    "Download video" : "Hämta video",
     "Keyboard shortcut" : "Tangentbordsgenvägar",
     "Description" : "Beskrivning",
     "right" : "Höger",
@@ -98,7 +98,7 @@ OC.L10N.register(
     "Disable full text" : "Avaktivera fulltext",
     "Unread updated" : "Markera som oläst",
     "Ignore updated" : "Ignorera uppdaterad",
-    "Open feed URL" : "Öppna flödes-URL",
+    "Open feed URL" : "Öppna flödeswebbadress",
     "Delete" : "Radera",
     "Dismiss" : "Avfärda",
     "Collapse" : "Dölj",
@@ -113,7 +113,7 @@ OC.L10N.register(
     "Expand articles on key navigation" : "Expandera artiklar vid hantering",
     "Show all articles" : "Visa alla artiklar",
     "Reverse ordering (oldest on top)" : "Omvänd ordning (äldst överst)",
-    "Subscriptions (OPML)" : "Prenumerationer (OPML)",
+    "Subscriptions (OPML)" : "Abonnemang (OPML)",
     "Import" : "Importera",
     "Export" : "Exportera",
     "Error when importing: File does not contain valid OPML" : "Fel vid importering: Fil innehåller inte giltig OPML",
